package com.duben.heliapp.mvp.presenters

import com.google.gson.JsonObject
import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.heliapp.manager.AppHttpManager
import com.duben.heliapp.mvp.model.BannerList
import com.duben.heliapp.mvp.model.BaseResponse
import com.duben.heliapp.mvp.views.FollowView
import java.util.HashMap

class FollowPresenter : BasePresenter<FollowView>() {

    fun getCollectList() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.collectList(),
                object : BaseSubscriber<BaseResponse<BannerList>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<BannerList>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.getCollectListSuc(baseResponse.data)
                            else -> {
                                view.getCollectListFail()
                                view.showToast(message)
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)

                        view.getCollectListFail()
                    }

                })

    }

    fun cancelCollect(videoId: List<String>) {
        val vo = HashMap<String, Any>()
        vo["list"] = videoId
        AppHttpManager.getInstance(loanApplication)
            .call(
                loanService.cancelCollect(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.cancelCollectSuc()
                            else -> {
                                view.cancelCollectFail()
                                view.showToast(message)
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)

                        view.cancelCollectFail()
                    }

                })

    }


}